# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/get_account_info.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ledger_objects_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__objects__pb2
from . import amount_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2
from . import account_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2
from . import ledger_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2
from . import common_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/get_account_info.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n&org/xrpl/rpc/v1/get_account_info.proto\x12\x0forg.xrpl.rpc.v1\x1a$org/xrpl/rpc/v1/ledger_objects.proto\x1a\x1corg/xrpl/rpc/v1/amount.proto\x1a\x1dorg/xrpl/rpc/v1/account.proto\x1a\x1corg/xrpl/rpc/v1/ledger.proto\x1a\x1corg/xrpl/rpc/v1/common.proto\"\xb0\x01\n\x15GetAccountInfoRequest\x12\x30\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.AccountAddress\x12\x0e\n\x06strict\x18\x02 \x01(\x08\x12\x30\n\x06ledger\x18\x03 \x01(\x0b\x32 .org.xrpl.rpc.v1.LedgerSpecifier\x12\r\n\x05queue\x18\x04 \x01(\x08\x12\x14\n\x0csigner_lists\x18\x05 \x01(\x08\"\xd7\x01\n\x16GetAccountInfoResponse\x12\x32\n\x0c\x61\x63\x63ount_data\x18\x01 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.AccountRoot\x12\x30\n\x0bsigner_list\x18\x02 \x01(\x0b\x32\x1b.org.xrpl.rpc.v1.SignerList\x12\x14\n\x0cledger_index\x18\x03 \x01(\r\x12.\n\nqueue_data\x18\x04 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.QueueData\x12\x11\n\tvalidated\x18\x05 \x01(\x08\"\xe7\x01\n\tQueueData\x12\x11\n\ttxn_count\x18\x01 \x01(\r\x12\x1a\n\x12\x61uth_change_queued\x18\x02 \x01(\x08\x12\x17\n\x0flowest_sequence\x18\x03 \x01(\r\x12\x18\n\x10highest_sequence\x18\x04 \x01(\r\x12>\n\x15max_spend_drops_total\x18\x05 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.XRPDropsAmount\x12\x38\n\x0ctransactions\x18\x06 \x03(\x0b\x32\".org.xrpl.rpc.v1.QueuedTransaction\"\x97\x02\n\x11QueuedTransaction\x12\x13\n\x0b\x61uth_change\x18\x01 \x01(\x08\x12,\n\x03\x66\x65\x65\x18\x02 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.XRPDropsAmount\x12\x15\n\tfee_level\x18\x03 \x01(\x04\x42\x02\x30\x01\x12\x38\n\x0fmax_spend_drops\x18\x04 \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.XRPDropsAmount\x12+\n\x08sequence\x18\x05 \x01(\x0b\x32\x19.org.xrpl.rpc.v1.Sequence\x12\x41\n\x14last_ledger_sequence\x18\x06 \x01(\x0b\x32#.org.xrpl.rpc.v1.LastLedgerSequenceB\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
  ,
  dependencies=[org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__objects__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2.DESCRIPTOR,])




_GETACCOUNTINFOREQUEST = _descriptor.Descriptor(
  name='GetAccountInfoRequest',
  full_name='org.xrpl.rpc.v1.GetAccountInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='org.xrpl.rpc.v1.GetAccountInfoRequest.account', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='strict', full_name='org.xrpl.rpc.v1.GetAccountInfoRequest.strict', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger', full_name='org.xrpl.rpc.v1.GetAccountInfoRequest.ledger', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queue', full_name='org.xrpl.rpc.v1.GetAccountInfoRequest.queue', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signer_lists', full_name='org.xrpl.rpc.v1.GetAccountInfoRequest.signer_lists', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=219,
  serialized_end=395,
)


_GETACCOUNTINFORESPONSE = _descriptor.Descriptor(
  name='GetAccountInfoResponse',
  full_name='org.xrpl.rpc.v1.GetAccountInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_data', full_name='org.xrpl.rpc.v1.GetAccountInfoResponse.account_data', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signer_list', full_name='org.xrpl.rpc.v1.GetAccountInfoResponse.signer_list', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_index', full_name='org.xrpl.rpc.v1.GetAccountInfoResponse.ledger_index', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queue_data', full_name='org.xrpl.rpc.v1.GetAccountInfoResponse.queue_data', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validated', full_name='org.xrpl.rpc.v1.GetAccountInfoResponse.validated', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=398,
  serialized_end=613,
)


_QUEUEDATA = _descriptor.Descriptor(
  name='QueueData',
  full_name='org.xrpl.rpc.v1.QueueData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='txn_count', full_name='org.xrpl.rpc.v1.QueueData.txn_count', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auth_change_queued', full_name='org.xrpl.rpc.v1.QueueData.auth_change_queued', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lowest_sequence', full_name='org.xrpl.rpc.v1.QueueData.lowest_sequence', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='highest_sequence', full_name='org.xrpl.rpc.v1.QueueData.highest_sequence', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_spend_drops_total', full_name='org.xrpl.rpc.v1.QueueData.max_spend_drops_total', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transactions', full_name='org.xrpl.rpc.v1.QueueData.transactions', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=616,
  serialized_end=847,
)


_QUEUEDTRANSACTION = _descriptor.Descriptor(
  name='QueuedTransaction',
  full_name='org.xrpl.rpc.v1.QueuedTransaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='auth_change', full_name='org.xrpl.rpc.v1.QueuedTransaction.auth_change', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fee', full_name='org.xrpl.rpc.v1.QueuedTransaction.fee', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fee_level', full_name='org.xrpl.rpc.v1.QueuedTransaction.fee_level', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_spend_drops', full_name='org.xrpl.rpc.v1.QueuedTransaction.max_spend_drops', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequence', full_name='org.xrpl.rpc.v1.QueuedTransaction.sequence', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_ledger_sequence', full_name='org.xrpl.rpc.v1.QueuedTransaction.last_ledger_sequence', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=850,
  serialized_end=1129,
)

_GETACCOUNTINFOREQUEST.fields_by_name['account'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_account__pb2._ACCOUNTADDRESS
_GETACCOUNTINFOREQUEST.fields_by_name['ledger'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__pb2._LEDGERSPECIFIER
_GETACCOUNTINFORESPONSE.fields_by_name['account_data'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__objects__pb2._ACCOUNTROOT
_GETACCOUNTINFORESPONSE.fields_by_name['signer_list'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__objects__pb2._SIGNERLIST
_GETACCOUNTINFORESPONSE.fields_by_name['queue_data'].message_type = _QUEUEDATA
_QUEUEDATA.fields_by_name['max_spend_drops_total'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._XRPDROPSAMOUNT
_QUEUEDATA.fields_by_name['transactions'].message_type = _QUEUEDTRANSACTION
_QUEUEDTRANSACTION.fields_by_name['fee'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._XRPDROPSAMOUNT
_QUEUEDTRANSACTION.fields_by_name['max_spend_drops'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_amount__pb2._XRPDROPSAMOUNT
_QUEUEDTRANSACTION.fields_by_name['sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._SEQUENCE
_QUEUEDTRANSACTION.fields_by_name['last_ledger_sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._LASTLEDGERSEQUENCE
DESCRIPTOR.message_types_by_name['GetAccountInfoRequest'] = _GETACCOUNTINFOREQUEST
DESCRIPTOR.message_types_by_name['GetAccountInfoResponse'] = _GETACCOUNTINFORESPONSE
DESCRIPTOR.message_types_by_name['QueueData'] = _QUEUEDATA
DESCRIPTOR.message_types_by_name['QueuedTransaction'] = _QUEUEDTRANSACTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetAccountInfoRequest = _reflection.GeneratedProtocolMessageType('GetAccountInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTINFOREQUEST,
  '__module__' : 'org.xrpl.rpc.v1.get_account_info_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetAccountInfoRequest)
  })
_sym_db.RegisterMessage(GetAccountInfoRequest)

GetAccountInfoResponse = _reflection.GeneratedProtocolMessageType('GetAccountInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTINFORESPONSE,
  '__module__' : 'org.xrpl.rpc.v1.get_account_info_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.GetAccountInfoResponse)
  })
_sym_db.RegisterMessage(GetAccountInfoResponse)

QueueData = _reflection.GeneratedProtocolMessageType('QueueData', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEDATA,
  '__module__' : 'org.xrpl.rpc.v1.get_account_info_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.QueueData)
  })
_sym_db.RegisterMessage(QueueData)

QueuedTransaction = _reflection.GeneratedProtocolMessageType('QueuedTransaction', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEDTRANSACTION,
  '__module__' : 'org.xrpl.rpc.v1.get_account_info_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.QueuedTransaction)
  })
_sym_db.RegisterMessage(QueuedTransaction)


DESCRIPTOR._options = None
_QUEUEDTRANSACTION.fields_by_name['fee_level']._options = None
# @@protoc_insertion_point(module_scope)



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from .account_pb2 import (
    AccountAddress as org___xrpl___rpc___v1___account_pb2___AccountAddress,
)

from .get_transaction_pb2 import (
    GetTransactionResponse as org___xrpl___rpc___v1___get_transaction_pb2___GetTransactionResponse,
)

from .ledger_pb2 import (
    LedgerRange as org___xrpl___rpc___v1___ledger_pb2___LedgerRange,
    LedgerSpecifier as org___xrpl___rpc___v1___ledger_pb2___LedgerSpecifier,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Union as typing___Union,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


class GetAccountTransactionHistoryRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    binary = ... # type: builtin___bool
    forward = ... # type: builtin___bool
    limit = ... # type: builtin___int

    @property
    def account(self) -> org___xrpl___rpc___v1___account_pb2___AccountAddress: ...

    @property
    def ledger_specifier(self) -> org___xrpl___rpc___v1___ledger_pb2___LedgerSpecifier: ...

    @property
    def ledger_range(self) -> org___xrpl___rpc___v1___ledger_pb2___LedgerRange: ...

    @property
    def marker(self) -> Marker: ...

    def __init__(self,
        *,
        account : typing___Optional[org___xrpl___rpc___v1___account_pb2___AccountAddress] = None,
        ledger_specifier : typing___Optional[org___xrpl___rpc___v1___ledger_pb2___LedgerSpecifier] = None,
        ledger_range : typing___Optional[org___xrpl___rpc___v1___ledger_pb2___LedgerRange] = None,
        binary : typing___Optional[builtin___bool] = None,
        forward : typing___Optional[builtin___bool] = None,
        limit : typing___Optional[builtin___int] = None,
        marker : typing___Optional[Marker] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> GetAccountTransactionHistoryRequest: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> GetAccountTransactionHistoryRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"account",u"ledger",u"ledger_range",u"ledger_specifier",u"marker"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"account",u"binary",u"forward",u"ledger",u"ledger_range",u"ledger_specifier",u"limit",u"marker"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"account",b"account",u"ledger",b"ledger",u"ledger_range",b"ledger_range",u"ledger_specifier",b"ledger_specifier",u"marker",b"marker"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"account",b"account",u"binary",b"binary",u"forward",b"forward",u"ledger",b"ledger",u"ledger_range",b"ledger_range",u"ledger_specifier",b"ledger_specifier",u"limit",b"limit",u"marker",b"marker"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"ledger",b"ledger"]) -> typing_extensions___Literal["ledger_specifier","ledger_range"]: ...

class GetAccountTransactionHistoryResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ledger_index_min = ... # type: builtin___int
    ledger_index_max = ... # type: builtin___int
    limit = ... # type: builtin___int
    validated = ... # type: builtin___bool

    @property
    def account(self) -> org___xrpl___rpc___v1___account_pb2___AccountAddress: ...

    @property
    def marker(self) -> Marker: ...

    @property
    def transactions(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[org___xrpl___rpc___v1___get_transaction_pb2___GetTransactionResponse]: ...

    def __init__(self,
        *,
        account : typing___Optional[org___xrpl___rpc___v1___account_pb2___AccountAddress] = None,
        ledger_index_min : typing___Optional[builtin___int] = None,
        ledger_index_max : typing___Optional[builtin___int] = None,
        limit : typing___Optional[builtin___int] = None,
        marker : typing___Optional[Marker] = None,
        transactions : typing___Optional[typing___Iterable[org___xrpl___rpc___v1___get_transaction_pb2___GetTransactionResponse]] = None,
        validated : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> GetAccountTransactionHistoryResponse: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> GetAccountTransactionHistoryResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"account",u"marker"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"account",u"ledger_index_max",u"ledger_index_min",u"limit",u"marker",u"transactions",u"validated"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"account",b"account",u"marker",b"marker"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"account",b"account",u"ledger_index_max",b"ledger_index_max",u"ledger_index_min",b"ledger_index_min",u"limit",b"limit",u"marker",b"marker",u"transactions",b"transactions",u"validated",b"validated"]) -> None: ...

class Marker(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ledger_index = ... # type: builtin___int
    account_sequence = ... # type: builtin___int

    def __init__(self,
        *,
        ledger_index : typing___Optional[builtin___int] = None,
        account_sequence : typing___Optional[builtin___int] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> Marker: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Marker: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"account_sequence",u"ledger_index"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"account_sequence",b"account_sequence",u"ledger_index",b"ledger_index"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from .account_pb2 import (
    AccountAddress as org___xrpl___rpc___v1___account_pb2___AccountAddress,
)

from .amount_pb2 import (
    XRPDropsAmount as org___xrpl___rpc___v1___amount_pb2___XRPDropsAmount,
)

from .common_pb2 import (
    LastLedgerSequence as org___xrpl___rpc___v1___common_pb2___LastLedgerSequence,
    Sequence as org___xrpl___rpc___v1___common_pb2___Sequence,
)

from .ledger_objects_pb2 import (
    AccountRoot as org___xrpl___rpc___v1___ledger_objects_pb2___AccountRoot,
    SignerList as org___xrpl___rpc___v1___ledger_objects_pb2___SignerList,
)

from .ledger_pb2 import (
    LedgerSpecifier as org___xrpl___rpc___v1___ledger_pb2___LedgerSpecifier,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Union as typing___Union,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


class GetAccountInfoRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    strict = ... # type: builtin___bool
    queue = ... # type: builtin___bool
    signer_lists = ... # type: builtin___bool

    @property
    def account(self) -> org___xrpl___rpc___v1___account_pb2___AccountAddress: ...

    @property
    def ledger(self) -> org___xrpl___rpc___v1___ledger_pb2___LedgerSpecifier: ...

    def __init__(self,
        *,
        account : typing___Optional[org___xrpl___rpc___v1___account_pb2___AccountAddress] = None,
        strict : typing___Optional[builtin___bool] = None,
        ledger : typing___Optional[org___xrpl___rpc___v1___ledger_pb2___LedgerSpecifier] = None,
        queue : typing___Optional[builtin___bool] = None,
        signer_lists : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> GetAccountInfoRequest: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> GetAccountInfoRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"account",u"ledger"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"account",u"ledger",u"queue",u"signer_lists",u"strict"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"account",b"account",u"ledger",b"ledger"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"account",b"account",u"ledger",b"ledger",u"queue",b"queue",u"signer_lists",b"signer_lists",u"strict",b"strict"]) -> None: ...

class GetAccountInfoResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ledger_index = ... # type: builtin___int
    validated = ... # type: builtin___bool

    @property
    def account_data(self) -> org___xrpl___rpc___v1___ledger_objects_pb2___AccountRoot: ...

    @property
    def signer_list(self) -> org___xrpl___rpc___v1___ledger_objects_pb2___SignerList: ...

    @property
    def queue_data(self) -> QueueData: ...

    def __init__(self,
        *,
        account_data : typing___Optional[org___xrpl___rpc___v1___ledger_objects_pb2___AccountRoot] = None,
        signer_list : typing___Optional[org___xrpl___rpc___v1___ledger_objects_pb2___SignerList] = None,
        ledger_index : typing___Optional[builtin___int] = None,
        queue_data : typing___Optional[QueueData] = None,
        validated : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> GetAccountInfoResponse: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> GetAccountInfoResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"account_data",u"queue_data",u"signer_list"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"account_data",u"ledger_index",u"queue_data",u"signer_list",u"validated"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"account_data",b"account_data",u"queue_data",b"queue_data",u"signer_list",b"signer_list"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"account_data",b"account_data",u"ledger_index",b"ledger_index",u"queue_data",b"queue_data",u"signer_list",b"signer_list",u"validated",b"validated"]) -> None: ...

class QueueData(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    txn_count = ... # type: builtin___int
    auth_change_queued = ... # type: builtin___bool
    lowest_sequence = ... # type: builtin___int
    highest_sequence = ... # type: builtin___int

    @property
    def max_spend_drops_total(self) -> org___xrpl___rpc___v1___amount_pb2___XRPDropsAmount: ...

    @property
    def transactions(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[QueuedTransaction]: ...

    def __init__(self,
        *,
        txn_count : typing___Optional[builtin___int] = None,
        auth_change_queued : typing___Optional[builtin___bool] = None,
        lowest_sequence : typing___Optional[builtin___int] = None,
        highest_sequence : typing___Optional[builtin___int] = None,
        max_spend_drops_total : typing___Optional[org___xrpl___rpc___v1___amount_pb2___XRPDropsAmount] = None,
        transactions : typing___Optional[typing___Iterable[QueuedTransaction]] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> QueueData: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> QueueData: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"max_spend_drops_total"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"auth_change_queued",u"highest_sequence",u"lowest_sequence",u"max_spend_drops_total",u"transactions",u"txn_count"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"max_spend_drops_total",b"max_spend_drops_total"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"auth_change_queued",b"auth_change_queued",u"highest_sequence",b"highest_sequence",u"lowest_sequence",b"lowest_sequence",u"max_spend_drops_total",b"max_spend_drops_total",u"transactions",b"transactions",u"txn_count",b"txn_count"]) -> None: ...

class QueuedTransaction(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    auth_change = ... # type: builtin___bool
    fee_level = ... # type: builtin___int

    @property
    def fee(self) -> org___xrpl___rpc___v1___amount_pb2___XRPDropsAmount: ...

    @property
    def max_spend_drops(self) -> org___xrpl___rpc___v1___amount_pb2___XRPDropsAmount: ...

    @property
    def sequence(self) -> org___xrpl___rpc___v1___common_pb2___Sequence: ...

    @property
    def last_ledger_sequence(self) -> org___xrpl___rpc___v1___common_pb2___LastLedgerSequence: ...

    def __init__(self,
        *,
        auth_change : typing___Optional[builtin___bool] = None,
        fee : typing___Optional[org___xrpl___rpc___v1___amount_pb2___XRPDropsAmount] = None,
        fee_level : typing___Optional[builtin___int] = None,
        max_spend_drops : typing___Optional[org___xrpl___rpc___v1___amount_pb2___XRPDropsAmount] = None,
        sequence : typing___Optional[org___xrpl___rpc___v1___common_pb2___Sequence] = None,
        last_ledger_sequence : typing___Optional[org___xrpl___rpc___v1___common_pb2___LastLedgerSequence] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> QueuedTransaction: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> QueuedTransaction: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"fee",u"last_ledger_sequence",u"max_spend_drops",u"sequence"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"auth_change",u"fee",u"fee_level",u"last_ledger_sequence",u"max_spend_drops",u"sequence"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"fee",b"fee",u"last_ledger_sequence",b"last_ledger_sequence",u"max_spend_drops",b"max_spend_drops",u"sequence",b"sequence"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"auth_change",b"auth_change",u"fee",b"fee",u"fee_level",b"fee_level",u"last_ledger_sequence",b"last_ledger_sequence",u"max_spend_drops",b"max_spend_drops",u"sequence",b"sequence"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from .amount_pb2 import (
    XRPDropsAmount as org___xrpl___rpc___v1___amount_pb2___XRPDropsAmount,
)

from typing import (
    Optional as typing___Optional,
    Union as typing___Union,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


class GetFeeRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    def __init__(self,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> GetFeeRequest: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> GetFeeRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...

class GetFeeResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    current_ledger_size = ... # type: builtin___int
    current_queue_size = ... # type: builtin___int
    expected_ledger_size = ... # type: builtin___int
    ledger_current_index = ... # type: builtin___int
    max_queue_size = ... # type: builtin___int

    @property
    def fee(self) -> Fee: ...

    @property
    def levels(self) -> FeeLevels: ...

    def __init__(self,
        *,
        current_ledger_size : typing___Optional[builtin___int] = None,
        current_queue_size : typing___Optional[builtin___int] = None,
        fee : typing___Optional[Fee] = None,
        expected_ledger_size : typing___Optional[builtin___int] = None,
        ledger_current_index : typing___Optional[builtin___int] = None,
        levels : typing___Optional[FeeLevels] = None,
        max_queue_size : typing___Optional[builtin___int] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> GetFeeResponse: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> GetFeeResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"fee",u"levels"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"current_ledger_size",u"current_queue_size",u"expected_ledger_size",u"fee",u"ledger_current_index",u"levels",u"max_queue_size"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"fee",b"fee",u"levels",b"levels"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"current_ledger_size",b"current_ledger_size",u"current_queue_size",b"current_queue_size",u"expected_ledger_size",b"expected_ledger_size",u"fee",b"fee",u"ledger_current_index",b"ledger_current_index",u"levels",b"levels",u"max_queue_size",b"max_queue_size"]) -> None: ...

class Fee(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def base_fee(self) -> org___xrpl___rpc___v1___amount_pb2___XRPDropsAmount: ...

    @property
    def median_fee(self) -> org___xrpl___rpc___v1___amount_pb2___XRPDropsAmount: ...

    @property
    def minimum_fee(self) -> org___xrpl___rpc___v1___amount_pb2___XRPDropsAmount: ...

    @property
    def open_ledger_fee(self) -> org___xrpl___rpc___v1___amount_pb2___XRPDropsAmount: ...

    def __init__(self,
        *,
        base_fee : typing___Optional[org___xrpl___rpc___v1___amount_pb2___XRPDropsAmount] = None,
        median_fee : typing___Optional[org___xrpl___rpc___v1___amount_pb2___XRPDropsAmount] = None,
        minimum_fee : typing___Optional[org___xrpl___rpc___v1___amount_pb2___XRPDropsAmount] = None,
        open_ledger_fee : typing___Optional[org___xrpl___rpc___v1___amount_pb2___XRPDropsAmount] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> Fee: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> Fee: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"base_fee",u"median_fee",u"minimum_fee",u"open_ledger_fee"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"base_fee",u"median_fee",u"minimum_fee",u"open_ledger_fee"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"base_fee",b"base_fee",u"median_fee",b"median_fee",u"minimum_fee",b"minimum_fee",u"open_ledger_fee",b"open_ledger_fee"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"base_fee",b"base_fee",u"median_fee",b"median_fee",u"minimum_fee",b"minimum_fee",u"open_ledger_fee",b"open_ledger_fee"]) -> None: ...

class FeeLevels(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    median_level = ... # type: builtin___int
    minimum_level = ... # type: builtin___int
    open_ledger_level = ... # type: builtin___int
    reference_level = ... # type: builtin___int

    def __init__(self,
        *,
        median_level : typing___Optional[builtin___int] = None,
        minimum_level : typing___Optional[builtin___int] = None,
        open_ledger_level : typing___Optional[builtin___int] = None,
        reference_level : typing___Optional[builtin___int] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> FeeLevels: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> FeeLevels: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"median_level",u"minimum_level",u"open_ledger_level",u"reference_level"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"median_level",b"median_level",u"minimum_level",b"minimum_level",u"open_ledger_level",b"open_ledger_level",u"reference_level",b"reference_level"]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/meta.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import ledger_objects_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__objects__pb2
from . import common_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/meta.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n\x1aorg/xrpl/rpc/v1/meta.proto\x12\x0forg.xrpl.rpc.v1\x1a$org/xrpl/rpc/v1/ledger_objects.proto\x1a\x1corg/xrpl/rpc/v1/common.proto\"\xd8\x01\n\x04Meta\x12\x1d\n\x11transaction_index\x18\x01 \x01(\x04\x42\x02\x30\x01\x12>\n\x12transaction_result\x18\x02 \x01(\x0b\x32\".org.xrpl.rpc.v1.TransactionResult\x12\x35\n\x0e\x61\x66\x66\x65\x63ted_nodes\x18\x03 \x03(\x0b\x32\x1d.org.xrpl.rpc.v1.AffectedNode\x12:\n\x10\x64\x65livered_amount\x18\x04 \x01(\x0b\x32 .org.xrpl.rpc.v1.DeliveredAmount\"\x91\x02\n\x11TransactionResult\x12\x42\n\x0bresult_type\x18\x01 \x01(\x0e\x32-.org.xrpl.rpc.v1.TransactionResult.ResultType\x12\x0e\n\x06result\x18\x02 \x01(\t\"\xa7\x01\n\nResultType\x12\x1b\n\x17RESULT_TYPE_UNSPECIFIED\x10\x00\x12\x13\n\x0fRESULT_TYPE_TEC\x10\x01\x12\x13\n\x0fRESULT_TYPE_TEF\x10\x02\x12\x13\n\x0fRESULT_TYPE_TEL\x10\x03\x12\x13\n\x0fRESULT_TYPE_TEM\x10\x04\x12\x13\n\x0fRESULT_TYPE_TER\x10\x05\x12\x13\n\x0fRESULT_TYPE_TES\x10\x06\"\x8d\x02\n\x0c\x41\x66\x66\x65\x63tedNode\x12;\n\x11ledger_entry_type\x18\x01 \x01(\x0e\x32 .org.xrpl.rpc.v1.LedgerEntryType\x12\x14\n\x0cledger_index\x18\x02 \x01(\x0c\x12\x34\n\x0c\x63reated_node\x18\x03 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.CreatedNodeH\x00\x12\x34\n\x0c\x64\x65leted_node\x18\x04 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.DeletedNodeH\x00\x12\x36\n\rmodified_node\x18\x05 \x01(\x0b\x32\x1d.org.xrpl.rpc.v1.ModifiedNodeH\x00\x42\x06\n\x04node\"@\n\x0b\x43reatedNode\x12\x31\n\nnew_fields\x18\x01 \x01(\x0b\x32\x1d.org.xrpl.rpc.v1.LedgerObject\"B\n\x0b\x44\x65letedNode\x12\x33\n\x0c\x66inal_fields\x18\x01 \x01(\x0b\x32\x1d.org.xrpl.rpc.v1.LedgerObject\"\xa6\x02\n\x0cModifiedNode\x12\x33\n\x0c\x66inal_fields\x18\x01 \x01(\x0b\x32\x1d.org.xrpl.rpc.v1.LedgerObject\x12\x36\n\x0fprevious_fields\x18\x02 \x01(\x0b\x32\x1d.org.xrpl.rpc.v1.LedgerObject\x12G\n\x17previous_transaction_id\x18\x03 \x01(\x0b\x32&.org.xrpl.rpc.v1.PreviousTransactionID\x12`\n$previous_transaction_ledger_sequence\x18\x04 \x01(\x0b\x32\x32.org.xrpl.rpc.v1.PreviousTransactionLedgerSequenceB\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
  ,
  dependencies=[org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__objects__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2.DESCRIPTOR,])



_TRANSACTIONRESULT_RESULTTYPE = _descriptor.EnumDescriptor(
  name='ResultType',
  full_name='org.xrpl.rpc.v1.TransactionResult.ResultType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESULT_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESULT_TYPE_TEC', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESULT_TYPE_TEF', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESULT_TYPE_TEL', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESULT_TYPE_TEM', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESULT_TYPE_TER', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESULT_TYPE_TES', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=441,
  serialized_end=608,
)
_sym_db.RegisterEnumDescriptor(_TRANSACTIONRESULT_RESULTTYPE)


_META = _descriptor.Descriptor(
  name='Meta',
  full_name='org.xrpl.rpc.v1.Meta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transaction_index', full_name='org.xrpl.rpc.v1.Meta.transaction_index', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'0\001', file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transaction_result', full_name='org.xrpl.rpc.v1.Meta.transaction_result', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='affected_nodes', full_name='org.xrpl.rpc.v1.Meta.affected_nodes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='delivered_amount', full_name='org.xrpl.rpc.v1.Meta.delivered_amount', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=116,
  serialized_end=332,
)


_TRANSACTIONRESULT = _descriptor.Descriptor(
  name='TransactionResult',
  full_name='org.xrpl.rpc.v1.TransactionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result_type', full_name='org.xrpl.rpc.v1.TransactionResult.result_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='result', full_name='org.xrpl.rpc.v1.TransactionResult.result', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRANSACTIONRESULT_RESULTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=335,
  serialized_end=608,
)


_AFFECTEDNODE = _descriptor.Descriptor(
  name='AffectedNode',
  full_name='org.xrpl.rpc.v1.AffectedNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_entry_type', full_name='org.xrpl.rpc.v1.AffectedNode.ledger_entry_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_index', full_name='org.xrpl.rpc.v1.AffectedNode.ledger_index', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_node', full_name='org.xrpl.rpc.v1.AffectedNode.created_node', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deleted_node', full_name='org.xrpl.rpc.v1.AffectedNode.deleted_node', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modified_node', full_name='org.xrpl.rpc.v1.AffectedNode.modified_node', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='node', full_name='org.xrpl.rpc.v1.AffectedNode.node',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=611,
  serialized_end=880,
)


_CREATEDNODE = _descriptor.Descriptor(
  name='CreatedNode',
  full_name='org.xrpl.rpc.v1.CreatedNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='new_fields', full_name='org.xrpl.rpc.v1.CreatedNode.new_fields', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=882,
  serialized_end=946,
)


_DELETEDNODE = _descriptor.Descriptor(
  name='DeletedNode',
  full_name='org.xrpl.rpc.v1.DeletedNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='final_fields', full_name='org.xrpl.rpc.v1.DeletedNode.final_fields', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=948,
  serialized_end=1014,
)


_MODIFIEDNODE = _descriptor.Descriptor(
  name='ModifiedNode',
  full_name='org.xrpl.rpc.v1.ModifiedNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='final_fields', full_name='org.xrpl.rpc.v1.ModifiedNode.final_fields', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_fields', full_name='org.xrpl.rpc.v1.ModifiedNode.previous_fields', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_transaction_id', full_name='org.xrpl.rpc.v1.ModifiedNode.previous_transaction_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_transaction_ledger_sequence', full_name='org.xrpl.rpc.v1.ModifiedNode.previous_transaction_ledger_sequence', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1017,
  serialized_end=1311,
)

_META.fields_by_name['transaction_result'].message_type = _TRANSACTIONRESULT
_META.fields_by_name['affected_nodes'].message_type = _AFFECTEDNODE
_META.fields_by_name['delivered_amount'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DELIVEREDAMOUNT
_TRANSACTIONRESULT.fields_by_name['result_type'].enum_type = _TRANSACTIONRESULT_RESULTTYPE
_TRANSACTIONRESULT_RESULTTYPE.containing_type = _TRANSACTIONRESULT
_AFFECTEDNODE.fields_by_name['ledger_entry_type'].enum_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__objects__pb2._LEDGERENTRYTYPE
_AFFECTEDNODE.fields_by_name['created_node'].message_type = _CREATEDNODE
_AFFECTEDNODE.fields_by_name['deleted_node'].message_type = _DELETEDNODE
_AFFECTEDNODE.fields_by_name['modified_node'].message_type = _MODIFIEDNODE
_AFFECTEDNODE.oneofs_by_name['node'].fields.append(
  _AFFECTEDNODE.fields_by_name['created_node'])
_AFFECTEDNODE.fields_by_name['created_node'].containing_oneof = _AFFECTEDNODE.oneofs_by_name['node']
_AFFECTEDNODE.oneofs_by_name['node'].fields.append(
  _AFFECTEDNODE.fields_by_name['deleted_node'])
_AFFECTEDNODE.fields_by_name['deleted_node'].containing_oneof = _AFFECTEDNODE.oneofs_by_name['node']
_AFFECTEDNODE.oneofs_by_name['node'].fields.append(
  _AFFECTEDNODE.fields_by_name['modified_node'])
_AFFECTEDNODE.fields_by_name['modified_node'].containing_oneof = _AFFECTEDNODE.oneofs_by_name['node']
_CREATEDNODE.fields_by_name['new_fields'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__objects__pb2._LEDGEROBJECT
_DELETEDNODE.fields_by_name['final_fields'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__objects__pb2._LEDGEROBJECT
_MODIFIEDNODE.fields_by_name['final_fields'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__objects__pb2._LEDGEROBJECT
_MODIFIEDNODE.fields_by_name['previous_fields'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_ledger__objects__pb2._LEDGEROBJECT
_MODIFIEDNODE.fields_by_name['previous_transaction_id'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._PREVIOUSTRANSACTIONID
_MODIFIEDNODE.fields_by_name['previous_transaction_ledger_sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._PREVIOUSTRANSACTIONLEDGERSEQUENCE
DESCRIPTOR.message_types_by_name['Meta'] = _META
DESCRIPTOR.message_types_by_name['TransactionResult'] = _TRANSACTIONRESULT
DESCRIPTOR.message_types_by_name['AffectedNode'] = _AFFECTEDNODE
DESCRIPTOR.message_types_by_name['CreatedNode'] = _CREATEDNODE
DESCRIPTOR.message_types_by_name['DeletedNode'] = _DELETEDNODE
DESCRIPTOR.message_types_by_name['ModifiedNode'] = _MODIFIEDNODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Meta = _reflection.GeneratedProtocolMessageType('Meta', (_message.Message,), {
  'DESCRIPTOR' : _META,
  '__module__' : 'org.xrpl.rpc.v1.meta_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Meta)
  })
_sym_db.RegisterMessage(Meta)

TransactionResult = _reflection.GeneratedProtocolMessageType('TransactionResult', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONRESULT,
  '__module__' : 'org.xrpl.rpc.v1.meta_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.TransactionResult)
  })
_sym_db.RegisterMessage(TransactionResult)

AffectedNode = _reflection.GeneratedProtocolMessageType('AffectedNode', (_message.Message,), {
  'DESCRIPTOR' : _AFFECTEDNODE,
  '__module__' : 'org.xrpl.rpc.v1.meta_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.AffectedNode)
  })
_sym_db.RegisterMessage(AffectedNode)

CreatedNode = _reflection.GeneratedProtocolMessageType('CreatedNode', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDNODE,
  '__module__' : 'org.xrpl.rpc.v1.meta_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.CreatedNode)
  })
_sym_db.RegisterMessage(CreatedNode)

DeletedNode = _reflection.GeneratedProtocolMessageType('DeletedNode', (_message.Message,), {
  'DESCRIPTOR' : _DELETEDNODE,
  '__module__' : 'org.xrpl.rpc.v1.meta_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.DeletedNode)
  })
_sym_db.RegisterMessage(DeletedNode)

ModifiedNode = _reflection.GeneratedProtocolMessageType('ModifiedNode', (_message.Message,), {
  'DESCRIPTOR' : _MODIFIEDNODE,
  '__module__' : 'org.xrpl.rpc.v1.meta_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.ModifiedNode)
  })
_sym_db.RegisterMessage(ModifiedNode)


DESCRIPTOR._options = None
_META.fields_by_name['transaction_index']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/xrp_ledger.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import get_account_info_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__info__pb2
from . import get_fee_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_get__fee__pb2
from . import submit_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_submit__pb2
from . import get_transaction_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_get__transaction__pb2
from . import get_account_transaction_history_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__transaction__history__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/xrp_ledger.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n org/xrpl/rpc/v1/xrp_ledger.proto\x12\x0forg.xrpl.rpc.v1\x1a&org/xrpl/rpc/v1/get_account_info.proto\x1a\x1dorg/xrpl/rpc/v1/get_fee.proto\x1a\x1corg/xrpl/rpc/v1/submit.proto\x1a%org/xrpl/rpc/v1/get_transaction.proto\x1a\x35org/xrpl/rpc/v1/get_account_transaction_history.proto2\xa0\x04\n\x13XRPLedgerAPIService\x12\x61\n\x0eGetAccountInfo\x12&.org.xrpl.rpc.v1.GetAccountInfoRequest\x1a\'.org.xrpl.rpc.v1.GetAccountInfoResponse\x12I\n\x06GetFee\x12\x1e.org.xrpl.rpc.v1.GetFeeRequest\x1a\x1f.org.xrpl.rpc.v1.GetFeeResponse\x12j\n\x11SubmitTransaction\x12).org.xrpl.rpc.v1.SubmitTransactionRequest\x1a*.org.xrpl.rpc.v1.SubmitTransactionResponse\x12\x61\n\x0eGetTransaction\x12&.org.xrpl.rpc.v1.GetTransactionRequest\x1a\'.org.xrpl.rpc.v1.GetTransactionResponse\x12\x8b\x01\n\x1cGetAccountTransactionHistory\x12\x34.org.xrpl.rpc.v1.GetAccountTransactionHistoryRequest\x1a\x35.org.xrpl.rpc.v1.GetAccountTransactionHistoryResponseB\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
  ,
  dependencies=[org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__info__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_get__fee__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_submit__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_get__transaction__pb2.DESCRIPTOR,org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__transaction__history__pb2.DESCRIPTOR,])



_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None

_XRPLEDGERAPISERVICE = _descriptor.ServiceDescriptor(
  name='XRPLedgerAPIService',
  full_name='org.xrpl.rpc.v1.XRPLedgerAPIService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=249,
  serialized_end=793,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetAccountInfo',
    full_name='org.xrpl.rpc.v1.XRPLedgerAPIService.GetAccountInfo',
    index=0,
    containing_service=None,
    input_type=org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__info__pb2._GETACCOUNTINFOREQUEST,
    output_type=org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__info__pb2._GETACCOUNTINFORESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetFee',
    full_name='org.xrpl.rpc.v1.XRPLedgerAPIService.GetFee',
    index=1,
    containing_service=None,
    input_type=org_dot_xrpl_dot_rpc_dot_v1_dot_get__fee__pb2._GETFEEREQUEST,
    output_type=org_dot_xrpl_dot_rpc_dot_v1_dot_get__fee__pb2._GETFEERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SubmitTransaction',
    full_name='org.xrpl.rpc.v1.XRPLedgerAPIService.SubmitTransaction',
    index=2,
    containing_service=None,
    input_type=org_dot_xrpl_dot_rpc_dot_v1_dot_submit__pb2._SUBMITTRANSACTIONREQUEST,
    output_type=org_dot_xrpl_dot_rpc_dot_v1_dot_submit__pb2._SUBMITTRANSACTIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetTransaction',
    full_name='org.xrpl.rpc.v1.XRPLedgerAPIService.GetTransaction',
    index=3,
    containing_service=None,
    input_type=org_dot_xrpl_dot_rpc_dot_v1_dot_get__transaction__pb2._GETTRANSACTIONREQUEST,
    output_type=org_dot_xrpl_dot_rpc_dot_v1_dot_get__transaction__pb2._GETTRANSACTIONRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetAccountTransactionHistory',
    full_name='org.xrpl.rpc.v1.XRPLedgerAPIService.GetAccountTransactionHistory',
    index=4,
    containing_service=None,
    input_type=org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__transaction__history__pb2._GETACCOUNTTRANSACTIONHISTORYREQUEST,
    output_type=org_dot_xrpl_dot_rpc_dot_v1_dot_get__account__transaction__history__pb2._GETACCOUNTTRANSACTIONHISTORYRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_XRPLEDGERAPISERVICE)

DESCRIPTOR.services_by_name['XRPLedgerAPIService'] = _XRPLEDGERAPISERVICE

# @@protoc_insertion_point(module_scope)
